Locale

Struct Locale 

pub struct Locale { /* private fields */ }
Locale

Implementations

Source

impl Locale

pub async fn graphql_ietf( &self, _: &Context<'_>, ) -> Result<&'static [&'static str]>

Available on crate features async-graphql and alloc only.

Returns the IETF locale code (e.g. en-US)

pub async fn graphql_timezones( &self, _: &Context<'_>, ) -> Result<&'static [&'static Timezone]>

Available on crate features async-graphql and alloc only.

Returns the list of tz database timezones

pub async fn graphql_date_formats( &self, _: &Context<'_>, ) -> Result<&'static StaticMap<&'static str, &'static str>>

Available on crate features async-graphql and alloc only.

Returns date formats for each IETF locale.

  • Key is the IETF code
  • Value is the date format, where:
    • G = era
    • y = year
    • M = month
    • d = day
pub async fn graphql_measurement_system( &self, _: &Context<'_>, ) -> Result<MeasurementSystem>

Available on crate features async-graphql and alloc only.

Returns system of measurement in use. see MeasurementSystem

pub async fn graphql_hour_clock(&self, _: &Context<'_>) -> Result<HourClock>

Available on crate features async-graphql and alloc only.

Returns the type of clock used. see HourClock

pub async fn graphql_driving_side(&self, _: &Context<'_>) -> Result<DrivingSide>

Available on crate features async-graphql and alloc only.

Returns the side of the road traffic drives on. see DrivingSide

pub async fn graphql_distance_unit( &self, _: &Context<'_>, ) -> Result<DistanceUint>

Available on crate features async-graphql and alloc only.

Returns the unit of distance used (kilometer or mile). see DistanceUint

pub async fn graphql_temperature_unit( &self, _: &Context<'_>, ) -> Result<TemperatureUint>

Available on crate features async-graphql and alloc only.

Returns the unit of temperature (celsius or fahrenheit). see TemperatureUint

pub async fn graphql_week_start_on(&self, _: &Context<'_>) -> Result<Day>

Available on crate features async-graphql and alloc only.

Returns which day is the first day of the week on the calendar. see Day

Source

impl Locale

pub const fn ietf(&self) -> &'static [&'static str]

Returns the IETF locale code (e.g. en-US)

pub const fn timezones(&self) -> &'static [&'static Timezone]

Returns the list of tz database timezones

pub const fn date_formats( &self, ) -> &'static StaticMap<&'static str, &'static str>

Returns date formats for each IETF locale.

  • Key is the IETF code
  • Value is the date format, where:
    • G = era
    • y = year
    • M = month
    • d = day
pub const fn measurement_system(&self) -> MeasurementSystem

Returns system of measurement in use. see MeasurementSystem

pub const fn hour_clock(&self) -> HourClock

Returns the type of clock used. see HourClock

pub const fn driving_side(&self) -> DrivingSide

Returns the side of the road traffic drives on. see DrivingSide

pub const fn distance_unit(&self) -> DistanceUint

Returns the unit of distance used (kilometer or mile). see DistanceUint

pub const fn temperature_unit(&self) -> TemperatureUint

Returns the unit of temperature (celsius or fahrenheit). see TemperatureUint

pub const fn week_start_on(&self) -> Day

Returns which day is the first day of the week on the calendar. see Day