pub struct Locale { /* private fields */ }Expand description
Locale
Implementations
Sourceimpl Locale
impl Locale
Sourcepub async fn graphql_ietf(
&self,
_: &Context<'_>,
) -> Result<&'static [&'static str]>
Available on crate features async-graphql and alloc only.
pub async fn graphql_ietf( &self, _: &Context<'_>, ) -> Result<&'static [&'static str]>
async-graphql and alloc only.Returns the IETF locale code (e.g. en-US)
Sourcepub async fn graphql_timezones(
&self,
_: &Context<'_>,
) -> Result<&'static [&'static Timezone]>
Available on crate features async-graphql and alloc only.
pub async fn graphql_timezones( &self, _: &Context<'_>, ) -> Result<&'static [&'static Timezone]>
async-graphql and alloc only.Returns the list of tz database timezones
Sourcepub async fn graphql_date_formats(
&self,
_: &Context<'_>,
) -> Result<&'static StaticMap<&'static str, &'static str>>
Available on crate features async-graphql and alloc only.
pub async fn graphql_date_formats( &self, _: &Context<'_>, ) -> Result<&'static StaticMap<&'static str, &'static str>>
async-graphql and alloc only.Returns date formats for each IETF locale.
- Key is the IETF code
- Value is the date format, where:
G= eray= yearM= monthd= day
Sourcepub async fn graphql_measurement_system(
&self,
_: &Context<'_>,
) -> Result<MeasurementSystem>
Available on crate features async-graphql and alloc only.
pub async fn graphql_measurement_system( &self, _: &Context<'_>, ) -> Result<MeasurementSystem>
async-graphql and alloc only.Returns system of measurement in use. see MeasurementSystem
Sourcepub async fn graphql_hour_clock(&self, _: &Context<'_>) -> Result<HourClock>
Available on crate features async-graphql and alloc only.
pub async fn graphql_hour_clock(&self, _: &Context<'_>) -> Result<HourClock>
async-graphql and alloc only.Returns the type of clock used. see HourClock
Sourcepub async fn graphql_driving_side(&self, _: &Context<'_>) -> Result<DrivingSide>
Available on crate features async-graphql and alloc only.
pub async fn graphql_driving_side(&self, _: &Context<'_>) -> Result<DrivingSide>
async-graphql and alloc only.Returns the side of the road traffic drives on. see DrivingSide
Sourcepub async fn graphql_distance_unit(
&self,
_: &Context<'_>,
) -> Result<DistanceUint>
Available on crate features async-graphql and alloc only.
pub async fn graphql_distance_unit( &self, _: &Context<'_>, ) -> Result<DistanceUint>
async-graphql and alloc only.Returns the unit of distance used (kilometer or mile). see DistanceUint
Sourcepub async fn graphql_temperature_unit(
&self,
_: &Context<'_>,
) -> Result<TemperatureUint>
Available on crate features async-graphql and alloc only.
pub async fn graphql_temperature_unit( &self, _: &Context<'_>, ) -> Result<TemperatureUint>
async-graphql and alloc only.Returns the unit of temperature (celsius or fahrenheit). see TemperatureUint
Sourceimpl Locale
impl Locale
Sourcepub const fn timezones(&self) -> &'static [&'static Timezone]
pub const fn timezones(&self) -> &'static [&'static Timezone]
Returns the list of tz database timezones
Sourcepub const fn date_formats(
&self,
) -> &'static StaticMap<&'static str, &'static str>
pub const fn date_formats( &self, ) -> &'static StaticMap<&'static str, &'static str>
Returns date formats for each IETF locale.
- Key is the IETF code
- Value is the date format, where:
G= eray= yearM= monthd= day
Sourcepub const fn measurement_system(&self) -> MeasurementSystem
pub const fn measurement_system(&self) -> MeasurementSystem
Returns system of measurement in use. see MeasurementSystem
Sourcepub const fn hour_clock(&self) -> HourClock
pub const fn hour_clock(&self) -> HourClock
Returns the type of clock used. see HourClock
Sourcepub const fn driving_side(&self) -> DrivingSide
pub const fn driving_side(&self) -> DrivingSide
Returns the side of the road traffic drives on. see DrivingSide
Sourcepub const fn distance_unit(&self) -> DistanceUint
pub const fn distance_unit(&self) -> DistanceUint
Returns the unit of distance used (kilometer or mile). see DistanceUint
Sourcepub const fn temperature_unit(&self) -> TemperatureUint
pub const fn temperature_unit(&self) -> TemperatureUint
Returns the unit of temperature (celsius or fahrenheit). see TemperatureUint
Sourcepub const fn week_start_on(&self) -> Day
pub const fn week_start_on(&self) -> Day
Returns which day is the first day of the week on the calendar. see Day